<?php

require_once('utils.php');
chdir ('../../');
require_once('api/Simpla.php');


Logger::info('Registered callback POST request: ' . json_encode($_POST));
$simpla = new Simpla();


$simpla_order_id = $_POST['OrderNumber'];

Logger::info("Searching for order with Id=" . $simpla_order_id);
$order = $simpla->orders->get_order(intval($simpla_order_id));
// Проверка существования заказа в базе
if (empty($order)) {
    Logger::error("Order with Id=" . $simpla_order_id . " not found");
    die();
}

// Проверка состояния оплаты
if ($order->paid) {
    Logger::error("Order with Id=" . $simpla_order_id . " is already paid");
    die();
}

// Достаем сущность метода оплаты
Logger::info("Searching for payment method...");
$payment_method = $simpla->payment->get_payment_method(intval($order->payment_method_id));
if(empty($payment_method)) {
    Logger::error("Unknown payment method");
    die();
}


// Проверяем, чтобы совпали суммы оплаты и заказа
Logger::info("Amount comparsion processing...");
$payture_notification_total = $_POST['Total'];
$order_amount = $simpla->money->convert($order->total_price, $method->currency_id, false);
if(floatval($order_amount) !== floatval($payture_notification_total) || $order_amount <= 0) {
    Logger::error("Invalid amount. Comparsion failed: " . floatval($order_amount) . " != " . floatval($payture_notification_total));
    die();
}

// Проверяем контрольную сумму
Logger::info("Processing check sum...");

$settings = unserialize($payment_method->settings);
$secret_key = !empty($settings['payture_secret_password']) ? $settings['payture_secret_password'] : "123";

$purchases = $simpla->orders->get_purchases(array('order_id'=>intval($order->id)));
$positions = array();
foreach ($purchases as $purchase)  {
    $product_name = htmlspecialchars(addslashes($purchase->product_name));
    $positions[] = array(
        "Quantity" => floatval($purchase->amount),
        "Price" => floatval($purchase->price),
        "Text" => $product_name
    );
}

$bundle = array(
    'OrderNumber' => $simpla_order_id,
    'Secret' => $secret_key,
    'TotalAmount' => $_POST['Amount'],
    'Products' => json_encode($positions)
);
$check_sum = sha1(join(';', array_map(function($key, $value) { return $key . '=' . $value; }, array_keys($bundle), array_values($bundle))));

if ( $check_sum !== $_POST['CheckSum'] ) {
    Logger::error("Invalid check sum. Comparsion failed: " . $check_sum . " != " . $_POST['CheckSum']);
    die();
}


// Проверка наличия товара на складе
Logger::info("Checking products in stock...");
$purchases = $simpla->orders->get_purchases(array('order_id'=>intval($order->id)));
$flag = false;
foreach($purchases as $purchase) {
	$variant = $simpla->variants->get_variant(intval($purchase->variant_id));
	if(empty($variant) || (!$variant->infinity && $variant->stock < $purchase->amount))
	{
        Logger::error("Variant not enough: " . $purchase->product_name . " " . $purchase->variant_name);
		$flag = true;
	}
}

// Если какого-то товара не хватает - выходим
if ($flag) {
    die();
}

if ( $_POST['Success'] !== 'True' ) {
    die();
}
    
// Обновляем статус заказа
Logger::info("Updating order in database...");
$simpla->orders->update_order(intval($order->id), array('paid'=>1));
$simpla->orders->close(intval($order->id));

// Оповещаем пользователя
Logger::info("Sending notification to customer...");
$simpla->notify->email_order_user(intval($order->id));
$simpla->notify->email_order_admin(intval($order->id));

echo "OK";

?>